#
# A edge object that can write itself in xgmml format for Cytoscape import
# - Teemu Kivioja, 2012
#

package XgmmlEdge;

use strict;
use warnings;

require Exporter;
our @ISA = qw(Exporter);


# 
# new edge from source node to target node, two XgmmlNode objects
#
sub new {

    my ($class, $label, $source_node, $target_node) = @_;
    my $self = {};
    
    $self->{label} = $label;
    $self->{source} = $source_node->get_label();
    $self->{target} = $target_node->get_label();

    $self->{source_node} = $source_node;
    $self->{target_node} = $target_node;

    $self->{attr} = {};

    bless($self, $class);
}



#
# Get source and object target nodes
#
sub get_source_node {
    my $self = shift;

    return $self->{source_node};
}


sub get_target_node {
    my $self = shift;

    return $self->{target_node};
}



#
# add attribute
#
sub add_attribute {
    my ($self, $label, $type, $value) = @_;

    my %attr = (label => $label,
		type => $type,
		val => $value);

    if (defined($self->{attr}->{$label})) {
	die "Error in XgmmlEdge: edge already has attribute $label";
    } else {
	$self->{attr}->{$label} = \%attr;
    }
}


# 
# get attribute value
#
sub get_attribute_value {
    my ($self, $label) = @_;
    
    return $self->{attr}->{$label};
}


#
# write the edge into a string
#
sub to_string {
    my $self = shift;

    my $str = "";
    my $label = $self->{label};
    my $source = $self->{source};
    my $target = $self->{target};

    $str = "<edge label=\"$label\" source=\"$source\" target=\"$target\">\n";
   
    for my $attr_label (keys %{ $self->{attr} }) {

	my $type = $self->{attr}->{$attr_label}->{type};
	my $val = $self->{attr}->{$attr_label}->{val};
	$str .= "    <att name=\"$attr_label\" label=\"$attr_label\" type=\"$type\" value=\"$val\"/>\n";
    }
    $str .= "</edge>\n";
    return $str;
}

1;
