#
# A node object that can write itself in xgmml format for Cytoscape import
# - Teemu Kivioja, 2012
#

package XgmmlNode;

use strict;
use warnings;

require Exporter;
our @ISA = qw(Exporter);


sub new {

    my ($class, $label) = @_;
    my $self = {};
    
    $self->{label} = $label;
    
    $self->{attr} = {};

    $self->{neighbors} = {};

    bless($self, $class);
    
}

# 
# "parent" node like each PWM has exactly one TF linked to it
#
sub parent {
    my $self = shift;

    if (@_) {
	$self->{parent} = shift;
    }

    return $self->{parent};

}


# 
# neighbors
#
sub add_neighbor {
    my ($self, $node) = @_;
    
    $self->{neighbors}->{$node} = $node;
}


sub get_neighbors {
    my $self = shift;
    
    my @neighbours = values %{ $self->{neighbors} };
    return \@neighbours;
}


sub degree {
    my $self = shift;
    
    return scalar(keys %{ $self->{neighbors} });

}


#
# Color number for visualization 
#
sub set_color {
    my ($self, $color) = @_;
    $self->{color} = $color;  
}

sub get_color {
    my $self = shift;
    return $self->{color};
}

#
# add attribute
# Note! new value does override existing value
#
sub add_attribute {
    my ($self, $label, $type, $value) = @_;

    my %attr = (label => $label,
		type => $type,
		val => $value);

    $self->{attr}->{$label} = \%attr;
}


# 
# get attribute value
#
sub get_attribute_value {
    my ($self, $label) = @_;
    
    if (defined($self->{attr}->{$label})) {
	return $self->{attr}->{$label}->{val};
    } else {
	return;
    }
}


sub get_label{
    my ($self) = @_;
    
    return $self->{label};
}




#
# write the node into a string
#
sub to_string {
    my $self = shift;

    my $str = "";
    my $label = $self->{label};

    #print STDERR "PRINT $label\n";
    $str = "<node name=\"base\" label=\"$label\">\n";
   
    for my $attr_label (keys %{ $self->{attr} }) {

	#print STDERR "\tATTR LABEL $attr_label\n";
	my $type = $self->{attr}->{$attr_label}->{type};
	my $val = $self->{attr}->{$attr_label}->{val};
	$str .= "    <att name=\"$attr_label\" label=\"$attr_label\" type=\"$type\" value=\"$val\"/>\n";
    }
    $str .= "</node>\n";
    return $str;
}

1;
